@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    https://imagemagick.org/script/license.php
+    https://imagemagick.org/license/
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,19 +30,19 @@ extern "C" {
 #define MagickLibVersion  0x712
 #define MagickLibVersionText  "7.1.2"
 #define MagickLibVersionNumber  10,0,2
-#define MagickLibAddendum  "-0"
+#define MagickLibAddendum  "-14 (Beta)"
 #define MagickLibInterface  10
 #define MagickLibMinInterface  10
 #define MagickPlatform  "x86_64"
 #define MagickppLibVersionText  "7.1.2"
 #define MagickppLibVersionNumber  5:0:0
-#define MagickppLibAddendum  "-0"
+#define MagickppLibAddendum  "-14 (Beta)"
 #define MagickppLibInterface  5
 #define MagickppLibMinInterface  5
-#define MagickGitRevision  "23234"
-#define MagickReleaseDate  "2025-07-13"
+#define MagickGitRevision  "23590"
+#define MagickReleaseDate  "2026-02-05"
 #define MagickAuthoritativeLicense  \
-  "https://imagemagick.org/script/license.php"
+  "https://imagemagick.org/license/"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-7/index.html"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
